@@ -34,7 +34,7 @@ except ImportError:  # Python 3
 if sys.version_info[:2] <= (2, 5):
     from core.backports import urllib3_python25 as urllib3
 else:
-    from core.bundle import urllib3
+    import urllib3
 from core import utils
 from core import rectangles
 from core import tiles
